Authors
=======

-  Fausto Marzi
-  Ryszard Chojnacki
-  Emil Dimitrov

Maintainers
===========

-  Fausto Marzi
-  Ryszard Chojnacki
-  Emil Dimitrov

Contributors
============

-  Duncan Thomas
-  Coleman Corrigan
-  Guillermo Ramirez Garcia
-  Zahari Zahariev
-  Eldar Nugaev
-  Saad Zaher
-  Samuel Bartel
-  Jonas Pfannschmidt
-  Deklan Dieterly
-  Pierre Mathieu

Credits
=======

-  Davide Guerri
-  Jim West
-  Lars Noldan
-  Stephen Pearson
-  Sneha Mini
-  Chris Delaney
-  James Bishop
-  Matt Joyce
-  Anupriya Ramraj
-  HP OpsAuto Team
-  Jon Otero Fernández (logo)
